@@ -836,9 +836,20 @@ class Vector4:
             y: float,
             z: float
     ):
-        roll = math.radians(x)
-        pitch = math.radians(y)
-        yaw = math.radians(z)
+        """
+        Creates a Vector3 object from x/y/z rotations (in radians).
+
+        Args:
+            x: Roll
+            y: Pitch
+            z: Yaw
+
+        Returns:
+            A new Vector3 object.
+        """
+        roll = x
+        pitch = y
+        yaw = z
 
         qx = math.sin(roll/2) * math.cos(pitch/2) * math.cos(yaw/2) - math.cos(roll/2) * math.sin(pitch/2) * math.sin(yaw/2)
         qy = math.cos(roll/2) * math.sin(pitch/2) * math.cos(yaw/2) + math.sin(roll/2) * math.cos(pitch/2) * math.sin(yaw/2)
@@ -847,6 +858,24 @@ class Vector4:
 
         return Vector4(qx, qy, qz, qw)
 
+    def to_euler(
+            self
+    ) -> Vector3:
+        t0 = 2.0 * (self.w*self.x + self.y*self.z)
+        t1 = 1 - 2*(self.x*self.x + self.y*self.y)
+        roll = math.atan2(t0, t1)
+
+        t2 = 2 * (self.w*self.y - self.z*self.x)
+        t2 = 1 if t2 > 1 else t2
+        t2 = -1 if t2 < -1 else t2
+        pitch = math.asin(t2)
+
+        t3 = 2 * (self.w*self.z + self.x*self.y)
+        t4 = 1 - 2*(self.y*self.y + self.z*self.z)
+        yaw = math.atan2(t3, t4)
+
+        return Vector3(roll, pitch, yaw)
+
     def magnitude(
             self
     ) -> float:
