@@ -79,11 +79,29 @@ class GFFFieldType(IntEnum):
     def return_type(
             self
     ):
-        if self in [GFFFieldType.UInt8, GFFFieldType.Int8, GFFFieldType.UInt16, GFFFieldType.Int16,
-                    GFFFieldType.UInt32, GFFFieldType.Int32, GFFFieldType.UInt16, GFFFieldType.UInt64]:
+        if self in [GFFFieldType.UInt8, GFFFieldType.UInt16, GFFFieldType.UInt32, GFFFieldType.UInt64,
+                    GFFFieldType.Int8, GFFFieldType.Int16, GFFFieldType.Int32, GFFFieldType.Int64]:
             return int
-        else:
+        elif self in [GFFFieldType.String]:
             return str
+        elif self in [GFFFieldType.ResRef]:
+            return ResRef
+        elif self in [GFFFieldType.Vector3]:
+            return Vector3
+        elif self in [GFFFieldType.Vector4]:
+            return Vector4
+        elif self in [GFFFieldType.LocalizedString]:
+            return LocalizedString
+        elif self in [GFFFieldType.Struct]:
+            return GFFStruct
+        elif self in [GFFFieldType.List]:
+            return GFFList
+        elif self in [GFFFieldType.Binary]:
+            return bytes
+        elif self in [GFFFieldType.Double, GFFFieldType.Single]:
+            return float
+        else:
+            raise ValueError(self)
 
 
 class GFF:
@@ -238,6 +256,12 @@ class GFFStruct:
         """
         return True if label in self._fields else None
 
+    def what_type(
+            self,
+            label: str
+    ) -> GFFFieldType:
+        return self._fields[label].field_type()
+
     def acquire(
             self,
             label: str,
@@ -263,6 +287,12 @@ class GFFStruct:
             value = self[label]
         return value
 
+    def value(
+            self,
+            label: str
+    ) -> Any:
+        return self._fields[label].value()
+
     def set_uint8(
             self,
             label: str,
